@@ -23,19 +23,6 @@ def test_provides_decorator():
     assert a['change_me'] == 'changed'
 
 
-@will_test(dont_inherit)
-def test_dont_inherit(config):
-    source_file = get_test_file('a_folder')
-    dont_inherit_keys = config['dont_inherit']
-    for key in dont_inherit_keys:
-        config[key] = 'gone!'
-    config['safe'] = 'safe'
-    config = dont_inherit(source_file, config)
-    for key in dont_inherit_keys:
-        assert not key in config
-    assert 'safe' in config
-
-
 @will_test(file_types)
 def test_file_types_folder(config):
     source_file = get_test_file('a_folder')
@@ -43,6 +30,13 @@ def test_file_types_folder(config):
     assert config['type'] == 'folder'
 
 
+@will_test(file_types)
+def test_file_types_root(config):
+    source_file = config['site_path']
+    config = file_types(source_file, config)
+    assert config['type'] == 'root'
+
+
 @will_test(file_types)
 def test_file_types_from_glob1(config):
     config.update({
